'''
File contains helper functions for binary Operations
'''

def convert16bitTo8bitList(list16bit):
    """
    Convert a list of 16-bit integers into a list of 8-bit integers.

    Args:
        list16bit (list): A list of 16-bit integers.

    Returns:
        list: A list of 8-bit integers.

    Example:
        >>> convert16bitTo8bitList([0x1234, 0xabcd])
        [18, 52, 171, 205]
    """
    list8bit = []
    for value in list16bit:
        a = (value >> 8) & 0xff
        b = value & 0xff
        list8bit.append(a)
        list8bit.append(b)
    return list8bit
    
    
def convert8bitTo16bitList(list8bit):
    """
    Convert a list of 8-bit integers into a list of 16-bit integers.

    If the input list has an odd number of elements, a zero is appended to the end
    to make it even.

    Args:
        list8bit (list): A list of 8-bit integers.

    Returns:
        list: A list of 16-bit integers.

    Example:
        >>> convert8bitTo16bitList([18, 52, 171, 205])
        [0x1234, 0xabcd]
    """
    list16bit = []
    if len(list8bit) % 2:
        list8bit.append(0)
    for i in range(0, len(list8bit), 2):
        byte0 = list8bit[i] << 8
        byte1 = list8bit[i+1]
        byte = byte0 + byte1
        list16bit.append(byte)
    return list16bit


from distutils.core import setup
setup(
  name = 'emBRICK',         # How you named your package folder (MyLib)
  packages = ['emBRICK'],   # Chose the same as "name"
  version = '0.21',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Driver to build a connection RemoteMaster <-> LWCS over Ethernet, Modbus TCP & RTU',   # Give a short description about your library
  author = 'IMACS',                   # Type in your name
  author_email = 'serkan.sen@imacs-gmbh.de',      # Type in your E-Mail
  url = 'https://github.com/IMACS-GmbH/emBRICK/tree/main/Protocol%20Stacks/remoteBUS/Python%20via%20TCP-IP%20or%20RSxxx',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/IMACS-GmbH/emBRICK/raw/main/Protocol%20Stacks/remoteBUS/Python%20via%20TCP-IP%20or%20RSxxx/emBRICK-0.15.tar.gz',    # I explain this later on
  keywords = ['IMACS', 'EMBRICK', 'PYTHON','TCP/IP','Modbus', 'RTU','TCP'],   # Keywords that define your package best
  install_requires=[            
          'threaded',
          'pyserial',
          'pymodbus>=3.2',
          'sockets',
          'DateTime',
          'numpy',
          'scipy'
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
  ],
)
